<?php

namespace App\Http\Middleware;

use Closure;
use Freelabois\LaravelQuickstart\Exceptions\ModelNotFound;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Lang;
use Schaffen\Core\Company\Repositories\CompanyRepository;

class CheckCompany
{
    /**
     * @var CompanyRepository
     */
    private $repository;

    public function __construct(CompanyRepository $repository)
    {
        $this->repository = $repository;
    }


    /**
     * Handle an incoming request.
     *
     * @param Request $request
     * @param Closure $next
     * @return mixed
     * @throws ModelNotFound
     */
    public function handle($request, Closure $next)
    {
        if (strpos($request->getUri(), "documents/financial")  !== false) {
            return $next($request);
        }

        if ($request->getMethod() === "OPTIONS") {
            return $next($request);
        }
        if(env('APP_ENV') === "dev") {
            $this->setEnvironmentDatabase();
            return $next($request);
        }

        //adaptado para o laravel passport e para a aplicação
        $urlExploded = explode(".", str_replace(['http://', 'https://'], "",
            $request->header('origin') ?? $request->header('OrigemAplicacao')));

        if (count($urlExploded) > 1)
            array_shift($urlExploded);

        $filters = [
            'notBlocked' => true,
            'emp_url_sistema' => implode(".", $urlExploded)
        ];

        //mobile não tem origin, no caso temos que retornar o header EmpBanco
        if ($request->header('EmpBanco') != '') {
            $filters = [
                'notBlocked' => true,
                'emp_banco' => $request->header('EmpBanco')
            ];
        }
        $db = $this->repository->first($filters);
        if (is_null($db)) {
            throw new ModelNotFound(Lang::get('exceptions.exception.db_not_found'));
        }

        $this->setEnvironmentDatabase($db);

        return $next($request);
    }

    public function setEnvironmentDatabase($db = null)
    {
        env('APP_ENV') !== "dev" ? config([
            'database.connections.dynamicdb' => [
                'driver' => 'pgsql',
                'host' => $db->emp_url,
                'port' => $db->emp_porta,
                'database' => $db->emp_banco,
                'username' => config('database.connections.pgsql.username'),
                'password' => config('database.connections.pgsql.password'),
                'schema' => 'acesso'
            ]
        ]) : config([
            'database.connections.dynamicdb' => [
                'driver' => 'pgsql',
                'host' =>  env('LOCAL_DATABASE_HOST'),
                'port' => env('LOCAL_DATABASE_PORT'),
                'database' => env('LOCAL_DATABASE'),
                'username' => env('LOCAL_DATABASE_USERNAME'),
                'password' => env('LOCAL_DATABASE_PASSWORD'),
                'schema' => 'acesso'
            ]
        ]);
    }
}
