<?php

namespace App\Mobile\Synchronization\Controllers;


use App\Mobile\Synchronization\Resources\SyncClientResource;
use App\Mobile\Synchronization\Resources\SyncStoreOrUpdateClientResource;
use Freelabois\LaravelQuickstart\Extendables\CrudController;
use Freelabois\LaravelQuickstart\Traits\Crudable;
use Illuminate\Http\Request;
use Schaffen\Core\Person\Managers\ClientManager;
use Schaffen\Core\Person\Managers\PersonManager;
use Schaffen\Core\Person\Repositories\PersonRepository;


class SyncClientController extends CrudController
{

    
    protected $resource = SyncStoreOrUpdateClientResource::class;

    public function __construct(ClientManager $manager, PersonRepository $repository)
    {
        parent::__construct($manager, $repository);
        $this->manager = $manager;
        $this->repository = $repository;

    }

    public function storeOrUpdate(Request $request)
    {
        $clients = $request->clients;
        $user = $request->user();
        $remainingClients = [];
        $ret = [];

        foreach ($clients as $client) {
            // Verifica se $client é um array antes de tentar manipular como tal
            if (!is_array($client)) {
                return response()->json([
                    'message' => 'Estrutura de cliente inválida. Esperado um array.',
                    'client' => $client
                ], 400);
            }
            
            $client['user'] = $user;

            try {
                $ret['clients'][] = $this->manager->storeOrUpdate($client);
            } catch (\Throwable $th) {
                // Adiciona os clientes restantes na lista
                $remainingClients = array_slice($clients, array_search($client, $clients) + 1);
                
                // Retorna a mensagem de erro junto com os clientes restantes
                return response()->json([
                    'message' => 'Houve um erro ao tentar cadastrar um cliente',
                    'remaining_clients' => $remainingClients,
                    'error' => $th->getMessage()
                ], 400);
            }
        }
        
        return response()->json($ret, 201);
    }

    


}
