<?php

namespace App\Mobile\Synchronization\Controllers;



use App\Mobile\Synchronization\Resources\SyncOrderResource;
use Freelabois\LaravelQuickstart\Extendables\CrudController;
use Illuminate\Http\Request;
use Schaffen\Core\Movement\Managers\SalesOrderManager;
use Schaffen\Core\Movement\Repositories\SalesOrderRepository;


class SyncOrderController extends CrudController
{
    protected string $resource = SyncOrderResource::class;

    public function __construct(
        SalesOrderManager    $manager,
        SalesOrderRepository $repository
    )
    {
        parent::__construct($manager, $repository);
        $this->manager = $manager;
        $this->repository = $repository;
    }

    public function ultimosPedidos(){
        $sanitized = \request()->all();
        return SyncOrderResource::collection($this->manager->ultimosPedidos($sanitized));
    }

    public function storeOrUpdate(Request $request){
        $orders = $request->orders;
        $user = $request->user();
        $remainingOrders = [];
        $ret = [];

        foreach ($orders as $order) {
            // Verifica se $client é um array antes de tentar manipular como tal
            if (!is_array($order)) {
                return response()->json([
                    'message' => 'Estrutura de pedido inválida. Esperado um array.',
                    'order' => $order
                ], 400);
            }
            
            $order['user'] = $user;

            try {
                $pedido = $this->manager->addPedido($order);
                $pedido["local_id"] = $order["local_id"];
                $ret['orders'][] = $pedido;
            } catch (\Throwable $th) {
                // Adiciona os pedidos restantes na lista
                $remainingOrders = array_slice($orders, array_search($order, $orders) + 1);
                
                // Retorna a mensagem de erro junto com os pedidos restantes
                return response()->json([
                    'message' => 'Houve um erro ao tentar cadastrar um pedido',
                    'remaining_orders' => $remainingOrders,
                    'error' => $th->getMessage()
                ], 400);
            }
        }
        
        return response()->json($ret, 201);

    }

    public function cancelarPedido(Request $request){
        $sanitized = $request->all();
        return new SyncOrderResource($this->manager->cancelarPedido($sanitized));
    }


}
