<?php

namespace App\RestApi\Person\Requests;

use Illuminate\Foundation\Http\FormRequest;

class AddressRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        switch ($this->method()) {
            case 'POST':
                return [
                    'pee_fk_pes_codigo' => 'required|integer|exists:dynamicdb.cadastro.pessoa,pes_codigo',
                    'pee_logradouro' => 'string|max:80|nullable',
                    'pee_numero' => 'string|max:10|nullable',
                    'pee_bairro' => 'string|max:80|nullable',
                    'pee_cep' => 'string|max:10|nullable',
                    'pee_pais' => 'string|max:30|nullable',
                    'pee_cidade' => 'string|max:80|nullable',
                    'pee_uf' => 'string|max:2|nullable',
                    'pee_padrao' => 'sometimes|integer|min:0|max:1',
                    'pee_complemento' => 'string|max:80|nullable',
                    'pee_latitude' => 'required_with:pee_longitude|numeric|nullable',
                    'pee_longitude' => 'required_with:pee_latitude|numeric|nullable',
                    'pee_tipo_endereco' => 'string|max:50|nullable',
                    'pee_fk_tpe_codigo' => 'integer|nullable|exists:dynamicdb.cadastro.tipo_endereco,tpe_codigo',
                    'pee_distancia_km' => 'numeric|nullable',
                    'pee_tipo_residencia' => 'string|max:50|nullable',
                    'pee_valor_aluguel' => 'numeric|nullable'
                ];
            case 'PUT':
                return [
                    'pee_fk_pes_codigo' => 'sometimes|integer|exists:dynamicdb.cadastro.pessoa,pes_codigo',
                    'pee_logradouro' => 'sometimes|string|max:80|nullable',
                    'pee_numero' => 'sometimes|string|max:10|nullable',
                    'pee_bairro' => 'sometimes|string|max:80|nullable',
                    'pee_cep' => 'sometimes|string|max:10|nullable',
                    'pee_pais' => 'sometimes|string|max:30|nullable',
                    'pee_cidade' => 'sometimes|string|max:80|nullable',
                    'pee_uf' => 'sometimes|string|max:2|nullable',
                    'pee_padrao' => 'sometimes|integer|min:0|max:1',
                    'pee_complemento' => 'sometimes|string|max:80|nullable',
                    'pee_latitude' => 'required_with:pee_longitude|numeric|nullable',
                    'pee_longitude' => 'required_with:pee_latitude|numeric|nullable',
                    'pee_tipo_endereco' => 'sometimes|string|max:50|nullable',
                    'pee_fk_tpe_codigo' => 'sometimes|integer|nullable|exists:dynamicdb.cadastro.tipo_endereco,tpe_codigo',
                    'pee_distancia_km' => 'sometimes|numeric|nullable',
                    'pee_tipo_residencia' => 'sometimes|string|max:50|nullable',
                    'pee_valor_aluguel' => 'sometimes|numeric|nullable'
                ];
            default:
                return [];
        }
    }

    public function attributes()
    {
        return [
            'pee_fk_pes_codigo' => trans('validation.attributes.person'),
            'pee_logradouro' => trans('validation.attributes.address'),
            'pee_numero' => trans('validation.attributes.address_number'),
            'pee_bairro' => trans('validation.attributes.district'),
            'pee_cep' => trans('validation.attributes.postal_code'),
            'pee_pais' => trans('validation.attributes.country'),
            'pee_cidade' => trans('validation.attributes.city'),
            'pee_uf' => trans('validation.attributes.state'),
            'pee_padrao' => trans('validation.attributes.default_address'),
            'pee_complemento' => trans('validation.attributes.complement'),
            'pee_latitude' => trans('validation.attributes.latitude'),
            'pee_longitude' => trans('validation.attributes.longitude'),
            'pee_tipo_endereco' => trans('validation.attributes.address_type'),
            'pee_fk_tpe_codigo' => trans('validation.attributes.address_type'),
            'pee_distancia_km' => trans('validation.attributes.distance'),
            'pee_tipo_residencia' => trans('validation.attributes.residence_type'),
            'pee_valor_aluguel' => trans('validation.attributes.rent_value')
        ];
    }


}
