<?php


namespace App\RestApi\ProductionOrder\Controllers;

use App\Http\Controller;
use App\RestApi\ProductionOrder\Requests\StoreCompositeProductRequest;
use App\RestApi\ProductionOrder\Requests\UpdateCompositeProductRequest;
use Freelabois\LaravelQuickstart\Traits\Crudable;
use Illuminate\Http\Request;
use Schaffen\Core\Product\Repositories\ProductVarietyPackRepository;
use Schaffen\ProductionOrder\ProductionOrder\Managers\CompositeProductManager;
use Schaffen\ProductionOrder\ProductionOrder\Repositories\CompositeProductRepository;

class CompositeProductController extends Controller
{
    //
    use Crudable;

    private $product_variety_pack_repository;

    public function __construct(
        CompositeProductManager $manager,
        CompositeProductRepository $repository,
        ProductVarietyPackRepository $product_variety_pack_repository
    )
    {
        $this->setup($manager, $repository);
        $this->product_variety_pack_repository = $product_variety_pack_repository;
    }

    public function store(StoreCompositeProductRequest $request)
    {
        return $this->manager->store($request->all());
    }

    public function update(UpdateCompositeProductRequest $request, $id) 
    {
        return $this->manager->update($request->all(), $id);
    }

    public function getByProductByFilters(Request $request)
    {
        $sanitized = $request->all();
        $sanitized['only_active'] = true;

        return $this->product_variety_pack_repository->findMany($sanitized, [
            'composition', 
            'product_variety', 
            'measurement_unit',
            'compositionQuantity'
        ]);
    }

    public function show($id)
    {
        return $this->product_variety_pack_repository->firstOrFail(["pve_codigo" => $id, "composition" => true],
            ['composition', 'product_variety'])
            ->load(['composition', 'product_variety']);

    }

    public function showHistoric($id) 
    {
        return $this->manager->showHistoric($id);
    }

    public function destroy($id)
    {
        return $this->manager->destroy($id);
    }

    public function index(Request $request)
    {
        $sanitized = [];
        $sanitized['composition'] = true;
        $sanitized['composition_filters'] = $request->all();

        return $this->product_variety_pack_repository->list($sanitized, [
            'measurement_unit', 
            'product_variety', 
            'composition',
            'composition.product_variety_pack',
            'composition.product_variety_pack.measurement_unit',
            'compositionQuantity'
        ]);
    }
}
